@@ -3,10 +3,26 @@
 #' @import assertthat
 #' @importFrom utils head tail
 #' @aliases NULL
-#' @section Getting started:
-#' See \code{\link{tbl_df}} for an introduction,
-#' \code{\link{data_frame}} and \code{\link{frame_data}} for construction,
-#' \code{\link{as_data_frame}} for coercion,
+#' @details The S3 class \code{tbl_df} wraps a local data frame. The main
+#' advantage to using a \code{tbl_df} over a regular data frame is the printing:
+#' tbl objects only print a few rows and all the columns that fit on one screen,
+#' describing the rest of it as text.
+#'
+#' @section Methods:
+#'
+#' \code{tbl_df} implements four important base methods:
+#'
+#' \describe{
+#' \item{print}{By default only prints the first 10 rows (at most 20), and the
+#'   columns that fit on screen; see \code{\link{print.tbl_df}}}
+#' \item{\code{[}}{Never simplifies (drops), so always returns data.frame}
+#' \item{\code{[[}, \code{$}}{Calls \code{\link{.subset2}} directly,
+#'   so is considerably faster. Returns \code{NULL} if column does not exist,
+#'   \code{$} warns.}
+#' }
+#' @section Important functions:
+#' \code{\link{tibble}} and \code{\link{frame_data}} for construction,
+#' \code{\link{as_tibble}} for coercion,
 #' and \code{\link{print.tbl_df}} and \code{\link{glimpse}} for display.
 "_PACKAGE"
 
@@ -26,7 +42,11 @@
 
   #' \item{\code{tibble.width}}{Output width. Default: \code{NULL} (use
   #'   \code{width} option).}
-  tibble.width = NULL
+  tibble.width = NULL,
+
+  #' \item{\code{tibble.max_extra_cols}}{Number of extra columns
+  #'   printed in reduced form. Default: 100.}
+  tibble.max_extra_cols = 100L
   #' }
 ))
 
